import { world, system, Player } from "@minecraft/server"

world.gameRules.sendCommandFeedback = false
world.gameRules.commandBlockOutput = false

const scoreboards = [
    "coins", "lives", "moving",
    "character", "settings", { displayName: "§bCharacter Chosen", id: "player" },
    "playerchose", "gameRunning", "frameenemy",
    "hp", "Iframes", "markers",
    "removelevitation", "goombamovement", "musictimer"
]
for (const objective of scoreboards) {
    const type = typeof objective
    if (world.scoreboard.getObjective(type === "string" ? objective : objective.id)) continue
    world.scoreboard.addObjective(type === "string" ? objective : objective.id, type === "object" ? objective.displayName : undefined)
}

system.runTimeout(() => {
    world.scoreboard.getObjective("musictimer")?.setScore("groundtheme", 0)
}, 200)

let coinObjective = world.scoreboard.getObjective("coins")
system.runTimeout(() => {
    coinObjective = world.scoreboard.getObjective("coins")
}, 2)

world.beforeEvents.worldInitialize.subscribe((data) => {
    data.blockComponentRegistry.registerCustomComponent("robotplatformer:coin_display", {
        onTick: (data) => {
            data.block.setType("air")
        }
    })
})

system.runInterval(() => {
    for (const player of world.getAllPlayers()) {
        if (!player.scoreboardIdentity) return
        if (!coinObjective) return
        const score = coinObjective.getScore(player)
        if (score === undefined) return
        player.onScreenDisplay.setActionBar(`§lx${score < 10 ? "0" : ""}${score}`)
    }
}, 20)

system.afterEvents.scriptEventReceive.subscribe((data) => {
    if (data.id !== "robotplatformer:death_screen") return
    if (!(data.sourceEntity instanceof Player)) return
    const player = data.sourceEntity
    player.onScreenDisplay.setTitle(`robotplatformer.death.${player.hasTag("player2") ? "luigi" : "mario"}`)
    player.inputPermissions.movementEnabled = false
    system.runTimeout(() => {
        if (player && player.isValid()) {player.onScreenDisplay.setTitle("§a"); player.inputPermissions.movementEnabled = true}
    }, 60)
})